# The `underactuated` python package

This package contains code to support the [Underactuated Robotics](http://underactuated.mit.edu) course notes.

```{eval-rst}
.. toctree::
   :maxdepth: 2

   meshcat_utils
   multibody
   plot_utils
   pyplot_utils
   utils
```

